
/*
 * FSDB_GO/src/fsdb_reader_internal_test.go
 * Copyright (c) 2016-2017 John Heidemann
 * All rights reserved.                                            
 *                                                                
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 */

package fsdb

import (
	"bytes"
//	"fmt"
	"fsdb"
	"io"
	"io/ioutil"
	"testing"
)

const (
	sampleInternalFsdb = `#fsdb -F t sid sname
1	dave
2	john
3	sugata
`
)

type internalClassTable struct {
	Sid int `col:"sid"`
	Name string `col:"sname"`
}

func TestReaderTwoStepWrapping(t *testing.T) {
	ioR := bytes.NewReader([]byte(sampleInternalFsdb))
	in, err := fsdb.NewFsdbReader(ioutil.NopCloser(ioR))
	if err != nil {
		panic("TestReaderFuncWrapping: cannot open NewFsdbReader")
	}

	var ct internalClassTable
	frs, err := in.MakeReadStructState(&ct, "col")
	if err != nil {
		panic("TestReaderFuncWrapping: MakeReadStructState failed")
	}
	for i := 1; true; i++ {
		err = in.ReadWithStructState(&ct, frs)
		if err != nil {
			if err != io.EOF {
				panic("error reading rows")
			}
			break
		}
		if ct.Sid != i {
			t.Errorf("TestReaderFuncWrapping: expected %d, got %d", i, ct.Sid)
		}
		// fmt.Println(i, ct.Sid, ct.Name)
        }
}

